==> 3050-PostSoftwareAssuranceTool-1.1.0-1.zip: LoginDlg.h <==
#if !defined(AFX_LOGINDLG_H__98114B78_7CA5_49B2_9E47_286387D55362__INCLUDED_)
#define AFX_LOGINDLG_H__98114B78_7CA5_49B2_9E47_286387D55362__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// LoginDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CLoginDlg dialog

class CLoginDlg : public CDialog
{
// Construction
public:
	CLoginDlg(CWnd* pParent = NULL);   // standard constructor
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );

//	enum { IDD = 130 IDD_LOGIN_DIALOG };

// Dialog Data
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	//{{AFX_DATA(CLoginDlg)
	enum { IDD = 130 };

	YButton	m_btnClose;
	YButton	m_btnLoginUser;
	YButton	m_btnLoginGuest;
	YButton	m_btnJoinMember;
	CButton	m_btnIsReportId;
	CEdit	m_edtPass;
	CEdit	m_edtId;
	CString	m_strId;
	CString	m_strPass;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CLoginDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CLoginDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnButtonGuest();
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnButtonJoinMember();
	afx_msg void OnButtonLogin();
	afx_msg void OnButtonClose();
	afx_msg void OnPaint();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_LOGINDLG_H__98114B78_7CA5_49B2_9E47_286387D55362__INCLUDED_)

==> 3050-PostSoftwareAssuranceTool-1.2.2-1.zip: LoginDlg.h <==
#if !defined(AFX_LOGINDLG_H__98114B78_7CA5_49B2_9E47_286387D55362__INCLUDED_)
#define AFX_LOGINDLG_H__98114B78_7CA5_49B2_9E47_286387D55362__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// LoginDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CLoginDlg dialog

class CLoginDlg : public CDialog
{
// Construction
public:
	CLoginDlg(CWnd* pParent = NULL);   // standard constructor
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );
	void SetWnd(HWND hwnd);
	void SetSocket ( CClientSocket* m_cClientSocket );
	void GiveJoinMemberAck ( int nResult );
//	enum { IDD = 130 IDD_LOGIN_DIALOG };

// Dialog Data
	BOOL			m_bFirst;
	CMemberJoinDlg	m_MemberJoinDlg;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	CMemberJoinDlg	m_MemberJoin;
	//{{AFX_DATA(CLoginDlg)
	enum { IDD = 130 };

	YButton	m_btnClose;
	YButton	m_btnLoginUser;
	YButton	m_btnLoginGuest;
	YButton	m_btnJoinMember;
	CButton	m_btnIsReportId;
	CEdit	m_edtPass;
	CEdit	m_edtId;
	CString	m_strId;
	CString	m_strPass;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CLoginDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CLoginDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnButtonGuest();
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnButtonJoinMember();
	afx_msg void OnButtonLogin();
	afx_msg void OnButtonClose();
	afx_msg void OnPaint();
	afx_msg HBRUSH OnCtlColor(CDC* pDC, CWnd* pWnd, UINT nCtlColor);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_LOGINDLG_H__98114B78_7CA5_49B2_9E47_286387D55362__INCLUDED_)
